Package: tractor.base
Version: 3.5.0
Date: 2025-10-13
Title: Read, Manipulate and Visualise Magnetic Resonance Images
Authors@R: person("Jon", "Clayden", role=c("cre","aut"),
    email="code@clayden.org", comment=c(ORCID="0000-0002-6608-0619"))
Imports: methods, ore (>= 1.3.0), RNifti (>= 1.8.0), reportr, shades
Suggests: mmand, loder, divest, yaml, tinytest
Enhances: oro.nifti
Description: Functions for working with magnetic resonance images. Reading and
    writing of popular file formats (DICOM, Analyze, NIfTI-1, NIfTI-2, MGH);
    interactive and non-interactive visualisation; flexible image manipulation;
    metadata and sparse image handling.
Encoding: UTF-8
License: GPL-2
URL: https://www.tractor-mri.org.uk, https://github.com/tractor/tractor
BugReports: https://github.com/tractor/tractor/issues
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-10-28 15:51:45 UTC; jon
Author: Jon Clayden [cre, aut] (ORCID: <https://orcid.org/0000-0002-6608-0619>)
Maintainer: Jon Clayden <code@clayden.org>
Repository: CRAN
Date/Publication: 2025-10-29 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 22:54:15 UTC; unix
