# Generated by roxygen2: do not edit by hand

S3method("dim<-",SparseArray)
S3method("pixdim<-",MriImage)
S3method("pixunits<-",MriImage)
S3method(Math,MriImage)
S3method(Ops,MriImage)
S3method(Summary,MriImage)
S3method(aperm,SparseArray)
S3method(as.array,MriImage)
S3method(as.array,SparseArray)
S3method(as.vector,SparseArray)
S3method(asDiffusionScheme,DiffusionScheme)
S3method(asDiffusionScheme,MriImage)
S3method(asDiffusionScheme,matrix)
S3method(dim,MriImage)
S3method(dim,SparseArray)
S3method(pixdim,MriImage)
S3method(pixunits,MriImage)
S3method(print,DicomMetadata)
S3method(print,fileSetHandle)
export(Optional)
export(allEqual)
export(angleBetweenVectors)
export(asDiffusionScheme)
export(asMriImage)
export(augmentedInfoPanel)
export(copyImageFiles)
export(createContactSheetGraphic)
export(createNeighbourhoodInfo)
export(createProjectionGraphic)
export(createSliceGraphic)
export(deduplicate)
export(deserialiseReferenceObject)
export(embrace)
export(emptyMatrix)
export(ensureFileSuffix)
export(equivalent)
export(execute)
export(expandFileName)
export(extractMriImage)
export(fi)
export(fillShells)
export(fx)
export(fxy)
export(fxyz)
export(getColourScale)
export(identifyImageFileNames)
export(imageFileExists)
export(imageFiles)
export(implode)
export(indexList)
export(is.emptyMatrix)
export(is.nilObject)
export(isDeserialisable)
export(locateExecutable)
export(loso)
export(matchPaths)
export(mergeMriImages)
export(newSparseArrayWithData)
export(nilObject)
export(pluralise)
export(polarPlotPanel)
export(printLabelledValues)
export(promote)
export(readDicomDirectory)
export(readDicomFile)
export(readDiffusionScheme)
export(readImageFile)
export(registerDeserialiser)
export(registerPathHandler)
export(relativePath)
export(removeImageFiles)
export(reorderMriImage)
export(resolvePath)
export(resolveVector)
export(serialiseReferenceObject)
export(sortDicomDirectories)
export(symlinkImageFiles)
export(threadSafeTempFile)
export(trimMriImage)
export(vectorCrossProduct)
export(vectorLength)
export(viewImages)
export(where)
export(writeDiffusionScheme)
export(writeImageFile)
exportClasses(DicomMetadata)
exportClasses(DiffusionScheme)
exportClasses(FileMap)
exportClasses(FileSet)
exportClasses(ImageFileSet)
exportClasses(MriImage)
exportClasses(SerialisableObject)
exportClasses(SparseArray)
exportClasses(TractorObject)
exportMethods("[")
exportMethods("[<-")
if (getRversion() < "4.4") export("%||%")
import(RNifti)
import(methods)
import(ore)
import(reportr)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRamp)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.off)
importFrom(grDevices,gray)
importFrom(grDevices,heat.colors)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,axis)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,lines)
importFrom(graphics,locator)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(stats,cor)
importFrom(stats,kmeans)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,read.table)
